@@ -46,6 +46,8 @@ class CommandHandler:
 
         args = self.tasks.options_handler.process_options(func, self.options)
 
+        self.tasks.__before__()
+
         # run task
         if isinstance(args, dict):
             func(**args)
@@ -54,6 +56,8 @@ class CommandHandler:
         else:
             func()
 
+        self.tasks.__after__()
+
     def help(self, option: Optional[str] = None):
         if option:
             task = getattr(self.tasks, option, None)
